package LATMOS::Accounts::Mail;

use strict;
use warnings;

use LATMOS::Accounts::Log;
use LATMOS::Accounts;
use Mail::Sendmail;
use Template;
use FindBin qw($Bin);
use Sys::Hostname;

sub new {
    my ($class, $la, $template, $headers) = @_;

    bless {
        _la => $la,
        template => $template,
        headers => $headers,
        _template => Template->new(
            INCLUDE_PATH => [
                ($la->val('_default_', 'templatespath')
                    ? $la->val('_default_', 'templatespath') . '/mail'
                    : ()),
                "$FindBin::Bin/../templates" . '/mail',
                '/usr/share/latmos-accounts/templates/mail',
            ],
            POST_CHOMP   => 1,
            EXTENSION    => '.mail',
        ),
    }, $class;
}

sub process {
    my ($self, $vars, $headers) = @_;

    my $message;
    $self->{_template}->process($self->{template}, $vars, \$message)
    or do {
        la_log(LA_ERR,
            "Cannot send mail: %s, exiting",
            $self->{_template}->error()
        );
        return;;
    };

    my %mail = (
        %{ $self->{headers} || {}},
        %{ $headers || {}},
        'Content-Type' => 'text/plain; charset=utf-8',
        smtp => $self->{_la}->val('_default_', 'smtp'),
        'X-LATMOS-Accounts' => $LATMOS::Accounts::VERSION,
        From => $self->{_la}->val('_default_', 'mailFrom', 'nomail@localhost'),
        'X-Mailer' => __PACKAGE__ . ' / ' . $LATMOS::Accounts::VERSION,

    );
    {
        my $package = __PACKAGE__;
        $package =~ s/::/./g;
        $mail{'Message-ID'} = join(
            '',
            '<', (map { unpack('H', chr(rand(255))) } (0..12)), '@',
            hostname(), '>' );
    }

    if (Mail::Sendmail::sendmail(
            %mail,
            Message => $message,
        )) {
        la_log(LA_DEBUG, "Mail for id %s sent to %s",
            $mail{'Message-ID'},
            $mail{to},
        );
        return 1;
    } else {
        la_log(LA_ERR, "Cannot send mail: %s", $Mail::Sendmail::error);
        return;
    }
}

1;
